@@ -23,7 +23,6 @@ See documentation for the StepPattern class.
 """
 
 import numpy
-import sys
 
 
 class StepPattern:
@@ -194,31 +193,34 @@ References
 
 -  (GiorginoJSS) Toni Giorgino. *Computing and Visualizing Dynamic Time
    Warping Alignments in R: The dtw Package.* Journal of Statistical
-   Software, 31(7), 1-24. http://www_jstatsoft_org/v31/i07/
+   Software, 31(7), 1-24.
+   `doi:10.18637/jss_v031.i07 <https://doi.org/10.18637/jss_v031.i07>`__
 -  (Itakura1975) Itakura, F., *Minimum prediction residual principle
    applied to speech recognition,* Acoustics, Speech, and Signal
    Processing, IEEE Transactions on , vol.23, no.1, pp. 67-72, Feb 1975.
-   URL: http://dx_doi_org/10.1109/TASSP.1975.1162641
+   `doi:10.1109/TASSP.1975.1162641 <https://doi.org/10.1109/TASSP.1975.1162641>`__
 -  (MRR1980) Myers, C.; Rabiner, L. & Rosenberg, A. *Performance
    tradeoffs in dynamic time warping algorithms for isolated word
    recognition*, IEEE Trans. Acoust., Speech, Signal Process., 1980, 28,
-   623-635. URL: http://dx_doi_org/10.1109/TASSP.1980.1163491
+   623-635.
+   `doi:10.1109/TASSP.1980.1163491 <https://doi.org/10.1109/TASSP.1980.1163491>`__
 -  (Mori2006) Mori, A.; Uchida, S.; Kurazume, R.; Taniguchi, R.;
    Hasegawa, T. & Sakoe, H. Early Recognition and Prediction of Gestures
    Proc. 18th International Conference on Pattern Recognition ICPR 2006,
-   2006, 3, 560-563. URL: http://dx_doi_org/10.1109/ICPR.2006.467
+   2006, 3, 560-563.
+   `doi:10.1109/ICPR.2006.467 <https://doi.org/10.1109/ICPR.2006.467>`__
 -  (Myers1980) Myers, Cory S. *A Comparative Study Of Several Dynamic
    Time Warping Algorithms For Speech Recognition*, MS and BS thesis,
    Dept. of Electrical Engineering and Computer Science, Massachusetts
    Institute of Technology, archived Jun 20 1980,
-   http://hdl_handle_net/1721.1/27909
+   https://hdl_handle_net/1721.1/27909
 -  (Rabiner1993) Rabiner, L. R., & Juang, B.-H. (1993). *Fundamentals of
    speech recognition.* Englewood Cliffs, NJ: Prentice Hall.
 -  (Sakoe1978) Sakoe, H.; Chiba, S., *Dynamic programming algorithm
    optimization for spoken word recognition,* Acoustics, Speech, and
    Signal Processing, IEEE Transactions on , vol.26, no.1, pp. 43-49,
-   Feb 1978 URL:
-   http://ieeexplore_ieee_org/xpls/abs_all_jsp?arnumber=1163055
+   Feb 1978
+   `doi:10.1109/TASSP.1978.1163055 <https://doi.org/10.1109/TASSP.1978.1163055>`__
 
 Examples
 --------
@@ -325,7 +327,7 @@ Hand-checkable example given in [Myers1980] p 61 - see JSS paper
         """Provide a visual description of a StepPattern object"""
         import matplotlib.pyplot as plt
         x = self.mx
-        pats = 1 + numpy.arange(self.get_n_patterns() + 1)
+        pats = numpy.arange(1, 1 + self.get_n_patterns())
 
         alpha = .5
         fudge = [0, 0]
